pub struct FittedComplementNB<F> { /* private fields */ }Expand description
Fitted Complement Naive Bayes classifier.
Implementations
Sourceimpl<F: Float + Send + Sync + 'static> FittedComplementNB<F>
impl<F: Float + Send + Sync + 'static> FittedComplementNB<F>
Sourcepub fn partial_fit(
&mut self,
x: &Array2<F>,
y: &Array1<usize>,
) -> Result<(), FerroError>
pub fn partial_fit( &mut self, x: &Array2<F>, y: &Array1<usize>, ) -> Result<(), FerroError>
Incrementally update the model with new data.
Accumulates feature counts and class counts, then recomputes the complement weights.
Errors
FerroError::ShapeMismatchifxandyhave different row counts or the number of features does not match the fitted model.FerroError::InvalidParameterif any feature value is negative.
Sourcepub fn predict_proba(&self, x: &Array2<F>) -> Result<Array2<F>, FerroError>
pub fn predict_proba(&self, x: &Array2<F>) -> Result<Array2<F>, FerroError>
Predict class probabilities for the given feature matrix.
Converts complement scores (lower=better) to probabilities by negating and applying softmax.
Returns shape (n_samples, n_classes) where each row sums to 1.
Errors
Returns FerroError::ShapeMismatch if the number of features does
not match the fitted model.